@@ -13,7 +13,8 @@ TO_ECEF_TEST_CASES = [
     ([0, 0, 0], [6378137, 0, 0]),
     ([7.43861, 46.951103, 552], [4325328, 564726.2, 4638459]),
     ([7.81512, 46.30447, 635.0], [4373351, 600250.4, 4589151]),
-    ([7.81471, 46.306686, 635.0], [4373179, 600194.8, 4589321]), ]
+    ([7.81471, 46.306686, 635.0], [4373179, 600194.8, 4589321]),
+]
 
 
 @pytest.mark.parametrize("llh_positions,exp_positions", TO_ECEF_TEST_CASES)
